/****************************************************************************
** Meta object code from reading C++ file 'terminal.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "terminal.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'terminal.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Terminal_t {
    QByteArrayData data[26];
    char stringdata0[325];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Terminal_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Terminal_t qt_meta_stringdata_Terminal = {
    {
QT_MOC_LITERAL(0, 0, 8), // "Terminal"
QT_MOC_LITERAL(1, 9, 16), // "cursorPosChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 6), // "newPos"
QT_MOC_LITERAL(4, 34, 15), // "termSizeChanged"
QT_MOC_LITERAL(5, 50, 4), // "rows"
QT_MOC_LITERAL(6, 55, 7), // "columns"
QT_MOC_LITERAL(7, 63, 20), // "displayBufferChanged"
QT_MOC_LITERAL(8, 84, 16), // "selectionChanged"
QT_MOC_LITERAL(9, 101, 24), // "scrollBackBufferAdjusted"
QT_MOC_LITERAL(10, 126, 5), // "reset"
QT_MOC_LITERAL(11, 132, 17), // "selectionFinished"
QT_MOC_LITERAL(12, 150, 8), // "keyPress"
QT_MOC_LITERAL(13, 159, 3), // "key"
QT_MOC_LITERAL(14, 163, 9), // "modifiers"
QT_MOC_LITERAL(15, 173, 4), // "text"
QT_MOC_LITERAL(16, 178, 24), // "printableLinesFromCursor"
QT_MOC_LITERAL(17, 203, 5), // "lines"
QT_MOC_LITERAL(18, 209, 9), // "putString"
QT_MOC_LITERAL(19, 219, 3), // "str"
QT_MOC_LITERAL(20, 223, 8), // "unEscape"
QT_MOC_LITERAL(21, 232, 18), // "pasteFromClipboard"
QT_MOC_LITERAL(22, 251, 24), // "copySelectionToClipboard"
QT_MOC_LITERAL(23, 276, 18), // "grabURLsFromBuffer"
QT_MOC_LITERAL(24, 295, 14), // "getUserMenuXml"
QT_MOC_LITERAL(25, 310, 14) // "clearSelection"

    },
    "Terminal\0cursorPosChanged\0\0newPos\0"
    "termSizeChanged\0rows\0columns\0"
    "displayBufferChanged\0selectionChanged\0"
    "scrollBackBufferAdjusted\0reset\0"
    "selectionFinished\0keyPress\0key\0modifiers\0"
    "text\0printableLinesFromCursor\0lines\0"
    "putString\0str\0unEscape\0pasteFromClipboard\0"
    "copySelectionToClipboard\0grabURLsFromBuffer\0"
    "getUserMenuXml\0clearSelection"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Terminal[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       2,  136, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   94,    2, 0x06 /* Public */,
       4,    2,   97,    2, 0x06 /* Public */,
       7,    0,  102,    2, 0x06 /* Public */,
       8,    0,  103,    2, 0x06 /* Public */,
       9,    1,  104,    2, 0x06 /* Public */,
      11,    0,  107,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      12,    3,  108,    2, 0x02 /* Public */,
      12,    2,  115,    2, 0x22 /* Public | MethodCloned */,
      16,    1,  120,    2, 0x02 /* Public */,
      18,    2,  123,    2, 0x02 /* Public */,
      18,    1,  128,    2, 0x22 /* Public | MethodCloned */,
      21,    0,  131,    2, 0x02 /* Public */,
      22,    0,  132,    2, 0x02 /* Public */,
      23,    0,  133,    2, 0x02 /* Public */,
      24,    0,  134,    2, 0x02 /* Public */,
      25,    0,  135,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QPoint,    3,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,   13,   14,   15,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   13,   14,
    QMetaType::QStringList, QMetaType::Int,   17,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,   19,   20,
    QMetaType::Void, QMetaType::QString,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::QStringList,
    QMetaType::QString,
    QMetaType::Void,

 // properties: name, type, flags
       5, QMetaType::Int, 0x00495001,
       6, QMetaType::Int, 0x00495001,

 // properties: notify_signal_id
       1,
       1,

       0        // eod
};

void Terminal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Terminal *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->cursorPosChanged((*reinterpret_cast< QPoint(*)>(_a[1]))); break;
        case 1: _t->termSizeChanged((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->displayBufferChanged(); break;
        case 3: _t->selectionChanged(); break;
        case 4: _t->scrollBackBufferAdjusted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->selectionFinished(); break;
        case 6: _t->keyPress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 7: _t->keyPress((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: { QStringList _r = _t->printableLinesFromCursor((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->putString((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 10: _t->putString((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 11: _t->pasteFromClipboard(); break;
        case 12: _t->copySelectionToClipboard(); break;
        case 13: { QStringList _r = _t->grabURLsFromBuffer();
            if (_a[0]) *reinterpret_cast< QStringList*>(_a[0]) = std::move(_r); }  break;
        case 14: { QString _r = _t->getUserMenuXml();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->clearSelection(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Terminal::*)(QPoint );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Terminal::cursorPosChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Terminal::*)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Terminal::termSizeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Terminal::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Terminal::displayBufferChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Terminal::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Terminal::selectionChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Terminal::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Terminal::scrollBackBufferAdjusted)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Terminal::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Terminal::selectionFinished)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Terminal *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->rows(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->columns(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Terminal::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Terminal.data,
    qt_meta_data_Terminal,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Terminal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Terminal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Terminal.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Terminal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Terminal::cursorPosChanged(QPoint _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Terminal::termSizeChanged(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Terminal::displayBufferChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Terminal::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Terminal::scrollBackBufferAdjusted(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Terminal::selectionFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
